@@ -7,6 +7,8 @@ class _unitConversion():
         self.scale = scale
         self.offset = offset
 
+
+
     def __mul__(self, other):
         if isinstance(other, _unitConversion):
             scale = self.scale * other.scale
@@ -24,15 +26,15 @@ class _unitConversion():
             scale *= self.scale
             offset*= self.scale
             offset += self.offset
-
+            
         return _unitConversion(scale, offset)
 
+
     def __truediv__(self, other):
         if isinstance(other, _unitConversion):
             return _unitConversion(1 / other.scale, - other.offset / other.scale) * self
         return self * _unitConversion(1 / other)
 
-
     def convert(self, value, useOffset=True):
         if useOffset:
             return self.scale * value + self.offset
@@ -357,8 +359,7 @@ class unit():
         self.unitStr = self._createUnitString()
 
         self._SIBaseUnit = self._getSIBaseUnit(self.upper, self.upperExp, self.lower, self.lowerExp)
-        otherUpper, otherUpperPrefix, otherUpperExp, otherLower, otherLowerPrefix, otherLowerExp = self._getLists(self._SIBaseUnit)
-        self._converterToSI = self._getConverter(otherUpper, otherUpperPrefix, otherUpperExp, otherLower, otherLowerPrefix, otherLowerExp)
+        self._converterToSI = self._getConverter(*self._getLists(self._SIBaseUnit))
 
     def _createUnitString(self):
         return self._combineUpperAndLower(self.upper, self.upperPrefix, self.upperExp, self.lower, self.lowerPrefix, self.lowerExp)
@@ -483,29 +484,26 @@ class unit():
         return out
 
     @staticmethod
-    def _splitUnitExponentAndPrefix(listOfUnitStrings):
-        n = len(listOfUnitStrings)
-        uList = [None] * n
-        prefixList = [None] * n
-        expList = [None] * n
-        for i in range(n):
-            prefixUnit, exponent = unit._removeExponentFromUnit(listOfUnitStrings[i])
-            u, prefix = unit._removePrefixFromUnit(prefixUnit)
-            uList[i] = u
-            prefixList[i] = prefix
-            expList[i] = exponent
-        return uList, prefixList, expList
+    def _splitUnitExponentAndPrefix(unitStr):
+        prefixUnit, exponent = unit._removeExponentFromUnit(unitStr)
+        u, prefix = unit._removePrefixFromUnit(prefixUnit)
+        return u, prefix, exponent
+
 
     @staticmethod
     def _getLists(unitStr):
         upper, lower = unit._splitCompositeUnit(unitStr)
-
-        upper, upperPrefix, upperExp = unit._splitUnitExponentAndPrefix(upper)
-        lower, lowerPrefix, lowerExp = unit._splitUnitExponentAndPrefix(lower)
-
+                
+        upper, upperPrefix, upperExp = map(list, zip(*[unit._splitUnitExponentAndPrefix(up) for up in upper]))
+        
         if lower:
+            lower, lowerPrefix, lowerExp = map(list, zip(*[unit._splitUnitExponentAndPrefix(low) for low in lower]))
             upper = ['DELTA' + elem if elem in temperature else elem for elem in upper]
             lower = ['DELTA' + elem if elem in temperature else elem for elem in lower]
+        else:
+            lowerPrefix = []
+            lowerExp = []
+
 
         return upper, upperPrefix, upperExp, lower, lowerPrefix, lowerExp
 
@@ -647,8 +645,6 @@ class unit():
       
         
         return unit.__formatUnit(unitStr)
-        
-    
             
     @staticmethod
     def __formatUnit(unitStr):
@@ -696,25 +692,21 @@ class unit():
 
     @ staticmethod
     def _removeExponentFromUnit(u):
+        
         integerIndexes = [i for i, char in enumerate(u) if char in integers]
-        exponent = 1
+        
         if not integerIndexes:
-            return u, exponent
+            return u, 1
 
-        # override the exponent if there are any integerindexes
-        if integerIndexes:
-            # determine if all integers are consectutive together
-            # sum(a, a+1, ... b-1, b) = (b * (b-1) - a * (a-1)) / 2
-            minIndex, maxIndex = integerIndexes[0] - 1, integerIndexes[-1]
-            if sum(integerIndexes) != (maxIndex * (maxIndex + 1) - minIndex * (minIndex + 1)) / 2:
+        for i in range(len(integerIndexes)-1):
+            if integerIndexes[i+1] - integerIndexes[i] != 1:
                 raise ValueError('All numbers in the unit has to be grouped together')
 
-            # Determine if the last integer is placed at the end of the unit
-            if integerIndexes[-1] != len(u) - 1:
-                raise ValueError('Any number has to be placed at the end of the unit')
+        # Determine if the last integer is placed at the end of the unit
+        if integerIndexes[-1] != len(u) - 1:
+            raise ValueError('Any number has to be placed at the end of the unit')
 
-            exponent = int(u[minIndex+1:])
-            u = u[:minIndex+1]
+        u, exponent = u[:integerIndexes[0]], int(u[integerIndexes[0]:])
 
 
         # Ensure that the entire use was not removed by removing the integers
@@ -781,38 +773,54 @@ class unit():
         return unit, prefix
 
     @staticmethod
-    def _getSIBaseUnit(upper, upperExp, lower, lowerExp):       
+    def _splitCompositeAndIncreaseExponent(unitStr, exp):
+            
+        up, low = unit._splitCompositeUnit(knownUnits[unitStr][0])
+        
+        up, upExp = map(list, zip(*[unit._removeExponentFromUnit(elem) for elem in up]))
+        low, lowExp = map(list, zip(*[unit._removeExponentFromUnit(elem) for elem in low])) if low else [[],[]]
+        
+        upExp = [elem * exp for elem in upExp]
+        lowExp = [elem * exp for elem in lowExp]
+        
+        return up, upExp, low, lowExp
+
+    @staticmethod
+    def _getSIBaseUnit(upper, upperExp, lower, lowerExp):    
+                
         nUpper = len(upper)
-        upperOut = []
-        lowerOut = []
-        upperExpOut = []
-        lowerExpOut = []
+        upperOut, lowerOut, upperExpOut, lowerExpOut = [], [], [], []
+        
         for i, (elem, exp) in enumerate(zip(upper + lower, upperExp + lowerExp)):
+            
             up,low = unit._splitCompositeUnit(knownUnits[elem][0])
+            
             if (i >= nUpper):
                 up, low = low, up
+            
             for elem in up:
                 elem, elemExp = unit._removeExponentFromUnit(elem)
+                elemExp *= exp
                 if not elem in upperOut:
                     upperOut.append(elem)
-                    upperExpOut.append(elemExp * exp)
+                    upperExpOut.append(elemExp)
                 else:
                     index = upperOut.index(elem)
-                    upperExpOut[index] += elemExp * exp
+                    upperExpOut[index] += elemExp
+                    
             for elem in low:
                 elem, elemExp = unit._removeExponentFromUnit(elem)
+                elemExp *= exp
                 if not elem in lowerOut:
                     lowerOut.append(elem)
-                    lowerExpOut.append(elemExp * exp)
+                    lowerExpOut.append(elemExp)
                 else:
                     index = lowerOut.index(elem)
-                    lowerExpOut[index] += elemExp * exp
-
-        upperPrefix = [None] * len(upperOut)
-        lowerPrefix = [None] * len(lowerOut)
+                    lowerExpOut[index] += elemExp
+        
         
         upper, upperPrefix, upperExp, lower, lowerPrefix, lowerExp = unit._cancleUnits(
-            upperOut, upperPrefix, upperExpOut, lowerOut, lowerPrefix, lowerExpOut
+            upperOut, [None] * len(upperOut), upperExpOut, lowerOut, [None] * len(lowerOut), lowerExpOut
         )
 
         return unit._combineUpperAndLower(upper, upperPrefix, upperExp, lower, lowerPrefix, lowerExp)
@@ -1073,7 +1081,7 @@ class unit():
 
         # determine if the SI bases are identical
         otherSIBase = self._getSIBaseUnit(otherUpper, otherUpperExp, otherLower, otherLowerExp)
-
+        
         if unit._assertEqualStatic(self._SIBaseUnit, otherSIBase) == False:
             raise ValueError(f'You tried to convert from {self} to {newUnit}. But these do not have the same base units')
         
@@ -1093,41 +1101,27 @@ class unit():
         # initialize the scale and offset
         out = _unitConversion(1, 0)
 
-        # get conversions for all upper and lower units in self
-        upperConversions = [knownUnits[elem][1] for elem in self.upper]
-        lowerConversions = [knownUnits[elem][1] for elem in self.lower]
-
-        # modify the scale and offset using the conversions
-        conversions = upperConversions + lowerConversions
-        nUpper = len(upperConversions)
+        nUpper = len(self.upper)
+        units = self.upper + self.lower 
         prefixes = self.upperPrefix + self.lowerPrefix
         exponents = self.upperExp + self.lowerExp
-        for i, (conv, prefix, exp) in enumerate(zip(conversions, prefixes, exponents)):
-            if exp > 1: conv = conv ** exp
+        for i, (unit, prefix, exp) in enumerate(zip(units, prefixes, exponents)):
+            conv = knownUnits[unit][1]
             if not prefix is None:
                 conv *= knownPrefixes[prefix]
-            if i < nUpper:
-                out *= conv
-            else:
-                out /= conv
-                        
-        # get all conversions from the upper and lower units in the new unit
-        upperConversions = [knownUnits[elem][1] for elem in otherUpper]
-        lowerConversions = [knownUnits[elem][1] for elem in otherLower]
+            if exp > 1: conv = conv ** exp
+            out = out * conv if i < nUpper else out / conv
 
-        # modify the scale and offset based on the conversions
-        conversions = upperConversions + lowerConversions
         nUpper = len(otherUpper)
+        units = otherUpper + otherLower
         prefixes = otherUpperPrefix + otherLowerPrefix
         exponents = otherUpperExp + otherLowerExp
-        for i, (conv, prefix, exp) in enumerate(zip(conversions, prefixes, exponents)):
-            if exp > 1: conv = conv ** exp
+        for i, (unit, prefix, exp) in enumerate(zip(units, prefixes, exponents)):
+            conv = knownUnits[unit][1]
             if not prefix is None:
                 conv *= knownPrefixes[prefix]
-            if i < nUpper:
-                out /= conv
-            else:
-                out *= conv
+            if exp > 1: conv = conv ** exp
+            out = out / conv if i < nUpper else out * conv
 
         return out
 
@@ -1148,10 +1142,3 @@ class unit():
         otherUpper, otherUpperPrefix, otherUpperExp, otherLower, otherLowerPrefix, otherLowerExp = self._getLists(self._SIBaseUnit)
         self._converterToSI = self._getConverter(otherUpper, otherUpperPrefix, otherUpperExp, otherLower, otherLowerPrefix, otherLowerExp)
 
-
-if __name__ == "__main__":
-    
-    print(unit('((s/m6)2)'))
-
-    
-    
\ No newline at end of file
