@@ -242,7 +242,7 @@ class scalarVariable():
         if not unit._assertEqualStatic(covUnit._SIBaseUnit, selfVarUnit._SIBaseUnit):
             raise ValueError(f'The covariance of {covariance} [{unitStr}] does not match the units of {self} and {var}')
         
-        covariance = covUnit._converterToSI.convert(covariance, useOffset=False)
+        covariance *= covUnit._converterToSI.convert(1, useOffset=False)
         
         self.covariance[var] = covariance        
         var.covariance[self] = covariance
@@ -278,7 +278,11 @@ class scalarVariable():
                 if var2 in self.dependsOn:
                     grad1 = self.dependsOn[var1][1]
                     grad2 = self.dependsOn[var2][1]
-                    variance += scale**2 * grad1 * grad2 * var1.covariance[var2]
+                    s = scale**2 
+                    cov = var1.covariance[var2]
+                    term = s * grad1 * grad2 * cov
+                    variance += term
+                    # variance += scale**2 * grad1 * grad2 * var1.covariance[var2]
 
         self._uncert = np.sqrt(variance)
         
@@ -932,7 +936,7 @@ class arrayVariable(scalarVariable):
             case np.sqrt:
                 return self.sqrt()
         raise NotImplementedError()
-    
+        
     def min(self):
         index = np.argmin(self.value)
         return variable(self.value[index], self.unit, self.uncert[index])
@@ -1000,10 +1004,9 @@ def variable(value, unit = '', uncert = None, nDigits = 3):
         return scalarVariable(value, unit, uncert, nDigits)
 
 
+
 if __name__ == "__main__":
-    A = variable(0.003, 'L/min', 0.2)
-    print(A)
-    a = variable(0.9, '', 3)
-    print(a)    
-    
+    diameter = variable(40, 'cm')
+    area = np.pi / 4 * diameter ** 2
     
+    print(area.value)
\ No newline at end of file
